function InitSubSysNames()
% InitSubSysNames
% Mike Anthony
% MathWorks
% Copyright (c) 2011, The MathWorks, Inc.
% All rights reserved.
%
% Redistribution and use in source and binary forms, with or without
% modification, are permitted provided that the following conditions are
% met:
%
%     * Redistributions of source code must retain the above copyright
%       notice, this list of conditions and the following disclaimer.
%     * Redistributions in binary form must reproduce the above copyright
%       notice, this list of conditions and the following disclaimer in
%       the documentation and/or other materials provided with the distribution
%     * Neither the name of the The MathWorks, Inc. nor the names
%       of its contributors may be used to endorse or promote products derived
%       from this software without specific prior written permission.
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
% AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
% IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
% ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
% LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
% CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
% SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
% INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
% CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
% ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
% POSSIBILITY OF SUCH DAMAGE.
%
%
% Sets Subsystem External Output Signal names to Subsystem Outport names.
%
% NOTE: A smarter version of this would have to follow the exectuion order
% and set signal/block names in that order. However, this is not that smart.
% Instead, just save a bunch of times and eventually it will fix all your
% names :-)

subs=find_system(bdroot,'LookUnderMasks','none','BlockType','SubSystem','Mask','off');

for i=1:length(subs)
    % Outputs
    try
        outs = find_system(subs{i},'SearchDepth',1,'BlockType','Outport');
        if length(outs) > 1
            disp(['        Subsystem ' subs{i} ' has Multiple Outports.']);
        end
        
        lineh = get_param(subs{i},'LineHandles');
        for j = 1:length(outs)
            name = get_param(outs{j},'Name');
            set_param(lineh.Outport(j),'Name',name);
        end
    catch
        disp(['        Subsystem ' subs{i} ' not connected or unamed outport...']);
    end
    
    % Inputs
    try
        ins = find_system(subs{i},'SearchDepth',1,'BlockType','Inport');
        if length(outs) > 1
            disp(['        Subsystem ' subs{i} ' has Multiple Inports.']);
        end
        
        lineh = get_param(subs{i},'LineHandles');
        for j = 1:length(ins)
            name = get_param(lineh.Inport(j),'Name');
            set_param(ins{j},'Name',name);
        end
    catch
        disp(['        Subsystem ' subs{i} ' not connected or unamed inport...']);
    end
end

