function InitTagNames()
% InitTagNames
% Mike Anthony
% MathWorks
% Copyright (c) 2011, The MathWorks, Inc.
% All rights reserved.
%
% Redistribution and use in source and binary forms, with or without
% modification, are permitted provided that the following conditions are
% met:
%
%     * Redistributions of source code must retain the above copyright
%       notice, this list of conditions and the following disclaimer.
%     * Redistributions in binary form must reproduce the above copyright
%       notice, this list of conditions and the following disclaimer in
%       the documentation and/or other materials provided with the distribution
%     * Neither the name of the The MathWorks, Inc. nor the names
%       of its contributors may be used to endorse or promote products derived
%       from this software without specific prior written permission.
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
% AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
% IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
% ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
% LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
% CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
% SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
% INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
% CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
% ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
% POSSIBILITY OF SUCH DAMAGE.
% 
% GOTO Tags inheirit incoming signal names.
% FROM Tags assign outgoing signal name that of block source parameter.
% Tags are resized to fit names in a readable way.
% 
% InitTagNames('model_name') : Checks all tags in that model 
%
% Simulink Model to be analyzed must be Open. 
% This enforces the use of only LOCAL scoped tags.

param=get_param(gcs,'Parent');
if isempty(param) == 1
    param=get_param(gcs,'Name');
    slsh=length(param)+1;
elseif isempty(findstr(param,'/')) == 1
    param=get_param(gcs,'Parent');
    slsh=length(param)+1;
else
    slsh=findstr(param,'/');
    param=param(1:slsh(1)-1);
end

currentpath=pwd;

gotolist=find_system(param,'LookUnderMasks','all','BlockType','Goto');
fromlist=find_system(param,'LookUnderMasks','all','BlockType','From');


% GOTO Tags Inheirit Signal Names
% ================================
for i=1:length(gotolist)
    set_param(gotolist{i},'TagVisibility','local');
    tempname=get_param(gotolist{i},'InputSignalNames');
    if strcmp('',tempname{1})
        gotoname{i}=get_param(gotolist{i},'GotoTag');
    elseif strcmp('<',tempname{1}(1))
        gotoname{i}=tempname{1}(2:(length(tempname{1})-1));
    else
        gotoname{i}=tempname{1};
    end
    name = get_param(gotolist{i},'Name');
%     if isempty(findstr(gotoname{i},name))
        pos = get_param(gotolist{i},'Position');
        ort = get_param(gotolist{i},'Orientation');
        dad = get_param(gotolist{i},'Parent');
        
        % Deleting and Adding allows use of the 'MakeNamenique' Property
        delete_block(gotolist{i});
        newblock = add_block('built-in/Goto',[dad '/' gotoname{i} '_GOTO'],'MakeNameUnique','on','Position',pos,'Orientation',ort);
        gotolist{i} = getfullname(newblock);
%     end
    set_param(gotolist{i},'GotoTag',gotoname{i});
    len = length(gotoname{i});
    set_param(gotolist{i},'Position',[pos(1) pos(2) pos(1)+len*10 pos(4)]);
    set_param(gotolist{i},'ShowName','off');
end

% FROM Tags Assign Signal Names
% ==============================
for i=1:length(fromlist)
    set_param(fromlist{i},'TagVisibility','local');
    fromport=get_param(fromlist{i},'PortHandles');
    linename=get_param(fromport.Outport(1),'Line');
    fromname{i}=get_param(fromlist{i},'GotoTag');
    name = get_param(fromlist{i},'Name');
%     if isempty(findstr(fromname{i},name))
        pos = get_param(fromlist{i},'Position');
        ort = get_param(fromlist{i},'Orientation');
        dad = get_param(fromlist{i},'Parent');
        
        % Deleting and Adding allows use of the 'MakeNamenique' Property
        delete_block(fromlist{i});
        newblock = add_block('built-in/From',[dad '/' fromname{i} '_FROM'],'MakeNameUnique','on','Position',pos,'Orientation',ort,'GotoTag',fromname{i});
        fromlist{i} = getfullname(newblock);
%     end
    if linename > 0
        set_param(linename,'Name',fromname{i});
    end
    len = length(fromname{i});
    set_param(fromlist{i},'Position',[pos(1) pos(2) pos(1)+len*10 pos(4)]);
    set_param(fromlist{i},'ShowName','off');
end
